api.system.components.configuration.v1.test_helpers.instance package — Argus-Toolbelt 1.0 documentation

# api.system.components.configuration.v1.test_helpers.instance package

## Submodules

## api.system.components.configuration.v1.test_helpers.instance.add_comment module

`api.system.components.configuration.v1.test_helpers.instance.add_comment.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/instance/w+/comment, respond with HTTP 403

`api.system.components.configuration.v1.test_helpers.instance.add_comment.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/instance/w+/comment, respond with HTTP 404

`api.system.components.configuration.v1.test_helpers.instance.add_comment.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/instance/w+/comment, respond with HTTP 200

`api.system.components.configuration.v1.test_helpers.instance.add_comment.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/instance/w+/comment, respond with HTTP 401

## api.system.components.configuration.v1.test_helpers.instance.create module

`api.system.components.configuration.v1.test_helpers.instance.create.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/instance, respond with HTTP 403

`api.system.components.configuration.v1.test_helpers.instance.create.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/instance, respond with HTTP 404

`api.system.components.configuration.v1.test_helpers.instance.create.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/instance, respond with HTTP 200

`api.system.components.configuration.v1.test_helpers.instance.create.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/instance, respond with HTTP 401

## api.system.components.configuration.v1.test_helpers.instance.delete module

`api.system.components.configuration.v1.test_helpers.instance.delete.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/instance/w+, respond with HTTP 403

`api.system.components.configuration.v1.test_helpers.instance.delete.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/instance/w+, respond with HTTP 404

`api.system.components.configuration.v1.test_helpers.instance.delete.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/instance/w+, respond with HTTP 200

`api.system.components.configuration.v1.test_helpers.instance.delete.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/instance/w+, respond with HTTP 401

## api.system.components.configuration.v1.test_helpers.instance.disable_monitoring module

`api.system.components.configuration.v1.test_helpers.instance.disable_monitoring.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/instance/w+/monitoring/disable, respond with HTTP 403

`api.system.components.configuration.v1.test_helpers.instance.disable_monitoring.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/instance/w+/monitoring/disable, respond with HTTP 404

`api.system.components.configuration.v1.test_helpers.instance.disable_monitoring.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/instance/w+/monitoring/disable, respond with HTTP 200

`api.system.components.configuration.v1.test_helpers.instance.disable_monitoring.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/instance/w+/monitoring/disable, respond with HTTP 401

## api.system.components.configuration.v1.test_helpers.instance.enable_monitoring module

`api.system.components.configuration.v1.test_helpers.instance.enable_monitoring.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/instance/w+/monitoring/enable, respond with HTTP 403

`api.system.components.configuration.v1.test_helpers.instance.enable_monitoring.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/instance/w+/monitoring/enable, respond with HTTP 404

`api.system.components.configuration.v1.test_helpers.instance.enable_monitoring.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/instance/w+/monitoring/enable, respond with HTTP 200

`api.system.components.configuration.v1.test_helpers.instance.enable_monitoring.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/instance/w+/monitoring/enable, respond with HTTP 401

## api.system.components.configuration.v1.test_helpers.instance.list module

`api.system.components.configuration.v1.test_helpers.instance.list.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/instance, respond with HTTP 403

`api.system.components.configuration.v1.test_helpers.instance.list.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/instance, respond with HTTP 404

`api.system.components.configuration.v1.test_helpers.instance.list.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/instance, respond with HTTP 200

`api.system.components.configuration.v1.test_helpers.instance.list.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/instance, respond with HTTP 401

## api.system.components.configuration.v1.test_helpers.instance.revisions module

`api.system.components.configuration.v1.test_helpers.instance.revisions.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/instance/w+/revisions, respond with HTTP 403

`api.system.components.configuration.v1.test_helpers.instance.revisions.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/instance/w+/revisions, respond with HTTP 404

`api.system.components.configuration.v1.test_helpers.instance.revisions.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/instance/w+/revisions, respond with HTTP 200

`api.system.components.configuration.v1.test_helpers.instance.revisions.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/instance/w+/revisions, respond with HTTP 401

## api.system.components.configuration.v1.test_helpers.instance.schedule_monitoring module

`api.system.components.configuration.v1.test_helpers.instance.schedule_monitoring.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/instance/w+/monitoring/schedule, respond with HTTP 403

`api.system.components.configuration.v1.test_helpers.instance.schedule_monitoring.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/instance/w+/monitoring/schedule, respond with HTTP 404

`api.system.components.configuration.v1.test_helpers.instance.schedule_monitoring.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/instance/w+/monitoring/schedule, respond with HTTP 200

`api.system.components.configuration.v1.test_helpers.instance.schedule_monitoring.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/instance/w+/monitoring/schedule, respond with HTTP 401

## api.system.components.configuration.v1.test_helpers.instance.search module

`api.system.components.configuration.v1.test_helpers.instance.search.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/instance/search, respond with HTTP 403

`api.system.components.configuration.v1.test_helpers.instance.search.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/instance/search, respond with HTTP 404

`api.system.components.configuration.v1.test_helpers.instance.search.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/instance/search, respond with HTTP 200

`api.system.components.configuration.v1.test_helpers.instance.search.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/instance/search, respond with HTTP 401

## api.system.components.configuration.v1.test_helpers.instance.update module

`api.system.components.configuration.v1.test_helpers.instance.update.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/instance/w+, respond with HTTP 403

`api.system.components.configuration.v1.test_helpers.instance.update.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/instance/w+, respond with HTTP 404

`api.system.components.configuration.v1.test_helpers.instance.update.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/instance/w+, respond with HTTP 200

`api.system.components.configuration.v1.test_helpers.instance.update.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/instance/w+, respond with HTTP 401

## api.system.components.configuration.v1.test_helpers.instance.view module

`api.system.components.configuration.v1.test_helpers.instance.view.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/instance/w+, respond with HTTP 403

`api.system.components.configuration.v1.test_helpers.instance.view.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/instance/w+, respond with HTTP 404

`api.system.components.configuration.v1.test_helpers.instance.view.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/instance/w+, respond with HTTP 200

`api.system.components.configuration.v1.test_helpers.instance.view.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/configuration/v1/instance/w+, respond with HTTP 401

## Module contents